@@ -1141,18 +1141,19 @@ PyMODINIT_FUNC initiMesh(void)
     import_helpers();
 
     /***** register C API *****/
-    static void *IMesh_API[7];
+    static void *IMesh_API[] = {
+        &iMesh_Type,
+        &iMeshIter_Type,
+        &iMeshEntitySet_Type,
+        &iMeshTag_Type,
+        &NPY_IMESHENTSET,
+        &NPY_IMESHTAG,
+        iMeshEntitySet_New,
+        iMeshTag_New,
+        &CreateEnt_Type,
+    };
     PyObject *api_obj;
 
-    /* Initialize the C API pointer array */
-    IMesh_API[0] = &iMesh_Type;
-    IMesh_API[1] = &iMeshIter_Type;
-    IMesh_API[2] = &iMeshEntitySet_Type;
-    IMesh_API[3] = &NPY_IMESHENTSET;
-    IMesh_API[4] = &iMeshTag_Type;
-    IMesh_API[5] = &NPY_IMESHTAG;
-    IMesh_API[6] = CreateEnt_Type;
-
     /* Create a CObject containing the API pointer array's address */
     api_obj = PyCObject_FromVoidPtr(IMesh_API,NULL);
 
