@@ -48,14 +48,17 @@ class TestEntSet(unittest.TestCase):
         self.assertEqual(self.geom.getNumOfType(iBase.Type.all), 1+6+12+8)
         self.assertFalse(self.set.contains(ents).any())
         self.assertEqual(self.set.getNumOfType(iBase.Type.all), 0)
+        self.assertEqual(len(self.set.getEntities(iBase.Type.all)), 0)
 
         self.set.add(ents)
         self.assert_(self.set.contains(ents).all())
         self.assertEqual(self.set.getNumOfType(iBase.Type.all), 1+6+12+8)
+        self.assertEqual(len(self.set.getEntities(iBase.Type.all)), 1+6+12+8)
 
         self.set.remove(ents)
         self.assertFalse(self.set.contains(ents).any())
         self.assertEqual(self.set.getNumOfType(iBase.Type.all), 0)
+        self.assertEqual(len(self.set.getEntities(iBase.Type.all)), 0)
 
     def testEntSet(self):
         sub = self.geom.createEntSet(True)
